/**
	@file main.d
	@brief 配下のスクリプトファイルを順序付け「NN.txt」に変換する。
	@par デフォルト動作
		@li デフォルト設定ファイル「nsccenv.yml」がある場合<br/>
			設定ファイルの記述に依存する。
		@li 上記が無い場合<br/>
			拡張子「nsc」で抽出し、カレントディレクトリを変換先として変換を実行する。
	@par ファイル名指定
		@li ファイル名[:番号]<br/>
			変換する対象となるファイル名。番号を指定した場合は、「番号.txt」に変換する。
	@par オプション
		@li -d:ディレクトリ名<br/>
			出力ディレクトリ。デフォルトはカレントフォルダ
		@li -ext:拡張子<br/>
			スクリプトファイルの拡張子。デフォルトは「nsc」
		@li -doextract<br/>
			ファイルの指定に関係なく抽出する。ただし、ファイル指定が優先される。
	@version 1.00
	@author senzogawa
	@par 更新履歴:
		@date 2006年6月24日 新規作成
		@date 2006年6月30日 クラス化、ファイル指定を追加。
		@date 2006年7月4日  番号指定を追加。
		@date 2006年7月5日  「送る」やドロップ操作に対応。
		@date 2006年7月6日  クラスを使わないような処理に修正。日本語ファイル名を有効にした。
		@date 2006年7月8日  更新時出力を追加。
		@date 2006年7月9日  バージョン情報表示を追加。設定ファイル読み込み機能を追加。
		@date 2006年7月10日  設定ファイル指定機能を追加。
	
	@usecase 配下の「.nsc」ファイルの名前を「番号.txt」に変換する
		@code
		nscc
		@endcode
	@usecase 使い方を表示する。
		@code
		nscc -help
		@endcode
	@usecase バージョンを表示する。
		@code
		nscc -version
		@endcode
	@usecase 「.nss」ファイルを変換し、「debug」フォルダに出力
		@code
		nscc -d:debug -ext:nss
		@endcode
	@usecase 「script.nss」、「scenario.txt」を変換する
		@code
		nscc script.nss scenario.txt
		@endcode
	@usecase 「define.nsc」を「0.txt」に、「start.nsc」を「1.txt」に変換する
		@code
		nscc define.nsc:0 start.nsc:1
		@endcode
	@usecase 「ヘッダ.nsc」が以前から更新されている時のみ「0.txt」に変換する
		@code
		nscc "ヘッダ.nsc:0" -doifmodified
		@endcode
**/

private import std.file;
private import std.path;

private import nscc.nscc;


int main(char[][] args)
{
	try{
		// カレントディレクトリの変更
		char[] exec_dir = getDirName(args[0]);
		if(exec_dir.length > 0){
			chdir(exec_dir);
		}
		NSCC nscc;
		if(args.length == 1){
			// 引数が無い場合はデフォルト動作
			nscc = NSCC.createBySettingFile(SETTING_FILE_DEFAULT);
		}
		else{
			nscc = NSCC.createByCommandLine(args);
		}
		nscc.execute();
	}
	catch(Exception e){
		printf("%s\n", std.file.toMBSz(e.toString));
	}
	return 0;
}
